Function width_str_max_unbroken

pub fn width_str_max_unbroken(s: &str, _word_break: WordBreak) -> usize
Like width_str but computes the width of the max unbroken (no line break) part of the string.

In certain cases, not even CSS’s word-break: break-all; (or equivalents) will be able to break a string, so it’s good to know how long the lines might get.

For example, try selecting the following unbroken part: ௌௌௌௌ