pub struct ContextProcessingOptions {
    pub block_if_muted: bool,
    pub block_if_empty: bool,
    pub block_if_severely_inappropriate: bool,
    pub character_limit: Option<NonZeroUsize>,
    pub rate_limit: Option<ContextRateLimitOptions>,
    pub repetition_limit: Option<ContextRepetitionLimitOptions>,
    pub max_safe_timeout: Duration,
    pub trim_whitespace: bool,
}
Options for customizing Context::process_with_options. Always initialize with ..Default::default(), as new fields may be added in the future.

Fields

block_if_muted: bool

Block messages if the user has been manually muted.

block_if_empty: bool

Block messages if they are empty (after whitespace is trimmed, if applicable).

block_if_severely_inappropriate: bool

Block messages, as opposed to censoring, if severe inappropriateness is detected.

character_limit: Option<NonZeroUsize>

Character count (or, with the width feature, number of m-equivalent widths).

Messages will be trimmed to fit.

rate_limit: Option<ContextRateLimitOptions>

Rate-limiting options.

repetition_limit: Option<ContextRepetitionLimitOptions>

Block messages if they are very similar to this many previous message.

max_safe_timeout: Duration

Maximum automatic “safe” timeouts can last. If set too high, users have more time/incentive to try and find ways around the system. If zero, “safe” timeouts won’t be used.

trim_whitespace: bool

Trim whitespace from beginning and end before returning censored output.