Struct rustrict::ContextRateLimitOptions
source · [−]pub struct ContextRateLimitOptions {
pub limit: Duration,
pub burst: u8,
pub character_limit: Option<NonZeroU16>,
}Expand description
Options that control rate-limiting.
Fields
limit: DurationMinimum time between messages (zero means infinite rate, 2s means 0.5 messages per second).
burst: u8Allows a certain amount of messages beyond the rate limit.
character_limit: Option<NonZeroU16>Count a message against the rate limit up to 3 times, once for each unit of this many characters.
If the width feature is enabled, the length of the text is interpreted as the number
of m’s it would take to reach the same length, or the number of characters, whichever
is higher.
Implementations