pub struct Type(_);
Type is represents a type or severity of inappropriateness. They can be combined with bitwise AND and OR operators, and are not mutually exclusive.

For example, the following means profane or at-least moderately mean: Type::PROFANE | (Type::MEAN & Type::MODERATE_OR_HIGHER)

Implementations

Bad words.

Offensive words.

Sexual words.

Mean words.

Words intended to evade detection.

Spam/gibberish/SHOUTING.

One of a very small number of safe phases. Recommended to enforce this on users who repeatedly evade the filter.

Not that bad.

Bad.

Cover your eyes!

Any level; Type::MILD, Type::MODERATE, or Type::SEVERE.

Any level in excess of Type::MILD.

The default Type, meaning profane, offensive, sexual, or severely mean.

Any type of detection (except SAFE). This will be expanded to cover all future types.

No type of detection.

Returns true if and only if self, the analysis result, meets the given threshold.

Logical opposite of Self::is.

👎Deprecated: this is for backwards-compatibility, use Type::NONE instead
👎Deprecated: this is for backwards-compatibility, compare with Type::NONE instead
👎Deprecated: this is for backwards-compatibility, there is no replacement