Trait rustrict::CensorIter

source ·
pub trait CensorIter {
    type Iterator: Iterator<Item = char>;

    fn censor(self) -> Self::Iterator;
}
CensorIter makes it easy to sanitize an arbitrary Iterator<Item=char> by calling .censor().

Required Associated Types

Required Methods

Iteratively censor characters, yielding (except accents) those that are not inappropriate, and replacing those that are with '*'.

Implementors