Enum rustrict::BlockReason
source · #[non_exhaustive]
pub enum BlockReason {
Inappropriate(Type),
Unsafe {
remaining: Duration,
targeted: bool,
},
Repetitious(usize),
Spam(Duration),
Muted(Duration),
Empty,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Inappropriate(Type)
The particular message was severely inappropriate, more specifically, Type.
Unsafe
Fields
remaining: Durationtargeted: boolWhether unsafe mode was targeted at this user (as opposed to configured globally).
Recent messages were generally inappropriate, and this message isn’t on the safe list.
Alternatively, if targeted is false, safe mode was configured globally.
Try again after Duration.
Repetitious(usize)
This message was too similar to usize recent messages.
Spam(Duration)
Too many messages per unit time, try again after Duration.
Muted(Duration)
Manually muted for Duration.
Empty
Message was, at least after censoring, completely empty.
Implementations
sourceimpl BlockReason
impl BlockReason
sourcepub fn generic_str(self) -> &'static str
pub fn generic_str(self) -> &'static str
You may display BlockReason in any manner you choose, but this will return a reasonable
default warning to send to the user.
pub fn contextual_str(self) -> String
sourcepub fn contextual_string(self) -> String
pub fn contextual_string(self) -> String
You may display BlockReason in any manner you choose, but this will return a reasonable
default warning to send to the user that includes some context (such as how long they are
muted for).