Censor is a flexible profanity filter that can analyze and/or censor arbitrary text.
You can also make use of Censor via traits CensorStr and CensorIter, which allow inline
checking and censoring of &str and Iterator<Item = char> respectively.
Implementations
sourceimpl<I: Iterator<Item = char>> Censor<I>
impl<I: Iterator<Item = char>> Censor<I>
sourcepub fn with_censor_threshold(&mut self, censor_threshold: Type) -> &mut Self
pub fn with_censor_threshold(&mut self, censor_threshold: Type) -> &mut Self
Selects a threshold to apply while censoring. Only words that meet or exceed the threshold are censored.
At present, Type::SPAM cannot be censored.
The default is [Type::Inappropriate].
sourcepub fn with_ignore_false_positives(
&mut self,
ignore_false_positives: bool
) -> &mut Self
pub fn with_ignore_false_positives(
&mut self,
ignore_false_positives: bool
) -> &mut Self
Censor words like “sh*t” in “push it,” which heavily increases false positives, but slightly decreases false negatives.
The default is false.
sourcepub fn with_ignore_self_censoring(
&mut self,
ignore_self_censoring: bool
) -> &mut Self
pub fn with_ignore_self_censoring(
&mut self,
ignore_self_censoring: bool
) -> &mut Self
Do not count instances of censor replacement in the input text as possible profanity.
If false, the input "****" will be assumed to be profane since if censor replacement is
set to '*'. This can help in cases like "mother******" where, if the user hadn’t self
censored, the censored version would have been "m***********".
At present, only affects analysis and not censoring.
The default is false.
sourcepub fn with_censor_first_character_threshold(
&mut self,
censor_first_character_threshold: Type
) -> &mut Self
pub fn with_censor_first_character_threshold(
&mut self,
censor_first_character_threshold: Type
) -> &mut Self
Censor all characters e.g. “xxxx,” instead of all but the first e.g. “fxxx,” if the word meets this threshold.
The default is false.
sourcepub fn with_censor_replacement(&mut self, censor_replacement: char) -> &mut Self
pub fn with_censor_replacement(&mut self, censor_replacement: char) -> &mut Self
Sets the character used to censor detected words.
The default is '*'.
sourcepub fn censor(&mut self) -> String
pub fn censor(&mut self) -> String
Produces a censored string. If called, it must be the first form of processing. It entirely consumes and censors the input characters.
Unfortunate Side Effects
All diacritical marks (accents) are removed by the current implementation. This is subject to change, as a better implementation would make this optional.
Panics
If called after analyze or a previous call to censor (except if reset is called in between).
sourcepub fn analyze(&mut self) -> Type
pub fn analyze(&mut self) -> Type
Fully analyzes a the input characters, to determine the type of inappropriateness present, if any.
The return value can be introspected with Type::is.
sourcepub fn censor_and_analyze(&mut self) -> (String, Type)
pub fn censor_and_analyze(&mut self) -> (String, Type)
See the documentation of censor and analyze.