pub struct Type(_);Expand description
Type is represents a type or severity of inappropriateness. They can be combined with bitwise AND and OR operators, and are not mutually exclusive.
For example, the following means profane or at-least moderately mean:
Type::PROFANE | (Type::MEAN & Type::MODERATE_OR_HIGHER)
Implementations
sourceimpl Type
impl Type
sourcepub const SAFE: Self = Self(TypeRepr::SAFE)
pub const SAFE: Self = Self(TypeRepr::SAFE)
One of a very small number of safe phases. Recommended to enforce this on users who repeatedly evade the filter.
sourcepub const MILD_OR_HIGHER: Self = Self(TypeRepr::MILD_OR_HIGHER)
pub const MILD_OR_HIGHER: Self = Self(TypeRepr::MILD_OR_HIGHER)
Any level; Type::MILD, Type::MODERATE, or Type::SEVERE.
sourcepub const MODERATE_OR_HIGHER: Self = Self(TypeRepr::MODERATE_OR_HIGHER)
pub const MODERATE_OR_HIGHER: Self = Self(TypeRepr::MODERATE_OR_HIGHER)
Any level in excess of Type::MILD.
sourcepub const INAPPROPRIATE: Self = Self(TypeRepr::INAPPROPRIATE)
pub const INAPPROPRIATE: Self = Self(TypeRepr::INAPPROPRIATE)
The default Type, meaning profane, offensive, sexual, or severely mean.
sourcepub const ANY: Self = Self(TypeRepr::ANY)
pub const ANY: Self = Self(TypeRepr::ANY)
Any type of detection (except SAFE). This will be expanded to cover all future types.
sourcepub fn is(self, threshold: Self) -> bool
pub fn is(self, threshold: Self) -> bool
Returns true if and only if self, the analysis result, meets the given threshold.
pub fn empty() -> Self
this is for backwards-compatibility, use Type::NONE instead
pub fn is_empty(self) -> bool
this is for backwards-compatibility, compare with Type::NONE instead
pub fn bits(self) -> u32
this is for backwards-compatibility, there is no replacement